@@ -1,4 +1,5 @@
 #include <dyncall.h>
+#include <dyncall_callback.h>
 #include <dynload.h>
 
 typedef struct
@@ -16,3 +17,12 @@ typedef struct
     DCpointer *fptr;
     Dyncall *lib;
 } DynXSub;
+
+typedef struct _callback
+{
+    SV *cb;
+    const char *signature;
+    char ret_type;
+    SV *userdata;
+    DCCallVM *cvm;
+} _callback;
